@@ -394,13 +394,14 @@ void save_positions_to_file(){
     return;
   }
 
+  if (new_head==NULL) {g_print("New_head is NULL\n");}
   while (new_head != NULL){
-      GSList * next_head=g_slist_next(new_head);
-      gps_info * cur_info=new_head->data;
-      //fprintf(fh,"%f:%f:%u\n",cur_info->lat,cur_info->lon,cur_info->date);
-      gps_positions=g_slist_remove(gps_positions, cur_info);
-      g_free(cur_info);
-      new_head=next_head;
+    GSList * next_head=g_slist_next(new_head);
+    gps_info * cur_info=new_head->data;
+    fprintf(fh,"%f:%f:%u\n",cur_info->lat,cur_info->lon,cur_info->date);
+    gps_positions=g_slist_remove(gps_positions, cur_info);
+    g_free(cur_info);
+    new_head=next_head;
   }
   fclose(fh);
 }
@@ -1168,13 +1169,14 @@ int main(int argc, char *argv[]) {
   //g_timeout_add(5000,my_timeout,(gpointer) mainloop);
   g_timeout_add(5*60*1000,monitor_connection,NULL);
   //fill_gps_positions_with_fake();
+  //send_gps_infos();  
   //save_positions_to_file();
 
   //g_slist_foreach(gps_positions, show_locations, NULL);
   //connection_available();
   //connection_available();
   //send_jpeg(NULL);
-  //send_gps_infos();  
+
   g_main_loop_run(mainloop);
   osso_deinitialize(osso_context);
 
